---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Code To Reproduce**
CLI commands or Python code snippet to reproduce the bug

```python
```

**Output**
Compete output obtained with maximal verbosity.

**Environment:**
 - Python version: `python --version`
 - sertit-utils version: `import sertit; sertit.__version__`

**Additional context**
Add any other context about the bug here.
